| generate_cost_matrix | R Documentation |
Generate a cost matrix for use with the search method.
generate_cost_matrix(charset, ambiguity_base = NULL, match = 0L, mismatch = 1L)
charset |
A string of all allowed characters in both query and target sequences (e.g. |
ambiguity_base |
A single character (e.g. |
match |
Integer cost of a match. |
mismatch |
Integer cost of a mismatch. |
A square cost matrix with row- and column-names given by charset, plus the optional ambiguity_base. Gap costs are no longer included here; pass gap_cost and gap_open_cost to distance/search functions.
generate_cost_matrix("ACGT", match = 0, mismatch = 1)
generate_cost_matrix("ACGT", ambiguity_base = "N", match = 0, mismatch = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.